@@ -1,11 +1,11 @@
 'use strict';
 
-var fs = require('fs').promises;
-var path = require('path');
-var {clearFileState, isFileStateModified, isFileStateDeleted, setCommittedFile} = require('../state');
+const fs = require('fs').promises;
+const path = require('path');
+const {clearFileState, isFileStateModified, isFileStateDeleted, setCommittedFile} = require('../state');
 
 async function write(file) {
-  var dir = path.dirname(file.path);
+  const dir = path.dirname(file.path);
   try {
     if (!(await fs.stat(dir)).isDirectory()) {
       throw new Error(`${file.path} is not a directory`);
@@ -18,18 +18,25 @@ async function write(file) {
     }
   }
 
-  await fs.writeFile(file.path, file.contents, {
-    mode: file.stat ? file.stat.mode : null
-  });
+  const options = {};
+  if (file.stat) {
+    options.mode = file.stat.mode;
+  }
+
+  await fs.writeFile(file.path, file.contents, options);
 }
 
 async function remove(file) {
-  let remove = fs.rm || fs.rmdir;
+  const remove = fs.rm || fs.rmdir;
   await remove(file.path, {recursive: true});
 }
 
 module.exports = async function (file) {
-  this.store.add(file);
+  const existingFile = this.store.get(file.path);
+  if (!existingFile || existingFile !== file) {
+    this.store.add(file);
+  }
+
   if (isFileStateModified(file)) {
     setCommittedFile(file);
     await write(file);
