@@ -2,9 +2,9 @@
 
 module.exports = function (filepath, options) {
   options = options || {raw: false};
-  var file = this.store.get(filepath);
+  const file = this.store.get(filepath);
 
-  if (file.state === 'deleted' || file.contents === null) {
+  if (file.contents === null) {
     if ('defaults' in options) {
       return options.defaults;
     }
